#!/usr/bin/env python3
"""
Model Configuration for ONEX Audit Event.

Strongly-typed configuration class for ONEX audit event.
"""


class ModelConfig:
    """Pydantic configuration for ONEX audit event."""


frozen = True
