"""
Health Detail Type Enum.

Canonical enum for health detail types used in component health monitoring.
"""

from enum import Enum


class EnumHealthDetailType(str, Enum):
    """Canonical health detail types for component monitoring."""

    INFO = "info"
    METRIC = "metric"
    WARNING = "warning"
    ERROR = "error"
    DIAGNOSTIC = "diagnostic"
